import 'package:flutter_driver/flutter_driver.dart';
import 'package:test/test.dart';

void main() {
  final startSessionButtonFinder = find.byValueKey('start_session');
  final counterFinder = find.byValueKey('counter');

  group('Kvalifika App', () {
    late FlutterDriver driver;

    setUpAll(() async {
      driver = await FlutterDriver.connect();
    });

    tearDownAll(() {
      driver.close();
    });

    test('check flutter driver health', () async {
      Health health = await driver.checkHealth();
      expect(health.status, HealthStatus.ok);
    });

    test(
      'SDK initializes',
      () async {
        await driver.waitFor(find.text('SDK Initialized'));
        expect(await driver.getText(counterFinder), '0');
      },
    );

    test('SDK starts session on button press', () async {
      await driver.tap(startSessionButtonFinder);
      await driver.waitFor(find.text('Started Verification'));
      expect(await driver.getText(counterFinder), '1');
    });

    test(
      'Session closes on timeout',
      () async {
        SerializableFinder finder = find.text('Timeout');
        await driver.waitFor(finder);
        expect(await driver.getText(finder), 'Timeout');
      },
      timeout: Timeout(
        Duration(minutes: 2),
      ),
    );
  });
}
